@@ -60,6 +60,7 @@
 #include "serial.h"
 #include "cli-out.h"
 #include "bt-utils.h"
+#include "terminal.h"
 
 /* The selected interpreter.  */
 std::string interpreter_p;
@@ -770,7 +771,10 @@ captured_main_1 (struct captured_main_args *context)
       OPT_EIX,
       OPT_EIEX,
       OPT_READNOW,
-      OPT_READNEVER
+      OPT_READNEVER,
+#ifdef USE_WIN32API
+      OPT_BINARY_OUTPUT,
+#endif
     };
     /* This struct requires int* in the struct, but write_files is a bool.
        So use this temporary int that we write back after argument parsing.  */
@@ -846,6 +850,9 @@ captured_main_1 (struct captured_main_args *context)
       {"args", no_argument, &set_args, 1},
       {"l", required_argument, 0, 'l'},
       {"return-child-result", no_argument, &return_child_result, 1},
+#ifdef USE_WIN32API
+      {"binary-output", no_argument, 0, OPT_BINARY_OUTPUT},
+#endif
       {0, no_argument, 0, 0}
     };
 
@@ -1019,6 +1026,12 @@ captured_main_1 (struct captured_main_args *context)
 	    }
 	    break;
 
+#ifdef USE_WIN32API
+	  case OPT_BINARY_OUTPUT:
+	    set_output_translation_mode_binary ();
+	    break;
+#endif
+
 	  case '?':
 	    error (_("Use `%s --help' for a complete list of options."),
 		   gdb_program_name);
@@ -1458,8 +1471,13 @@ Remote debugging options:\n\n\
 Other options:\n\n\
   --cd=DIR           Change current directory to DIR.\n\
   --data-directory=DIR, -D\n\
-		     Set GDB's data-directory to DIR.\n\
-"), stream);
+		     Set GDB's data-directory to DIR.\n"
+#ifdef USE_WIN32API
+"\
+  --binary-output    Set the translation mode of stdout/stderr to binary,\n\
+		     disabling CRLF translation.\n"
+#endif
+), stream);
   gdb_puts (_("\n\
 At startup, GDB reads the following early init files and executes their\n\
 commands:\n\
@@ -1503,7 +1521,7 @@ At startup, GDB reads the following init files and executes their commands:\n\
 For more information, type \"%ps\" from within GDB, or consult the\n\
 GDB manual (available as on-line info or a printed manual).\n\
 "),
-	      styled_string (command_style.style (), "stream"));
+	      styled_string (command_style.style (), "help"));
   if (REPORT_BUGS_TO[0] && stream == gdb_stdout)
     gdb_printf (stream, _("\n\
 Report bugs to %ps.\n\
